Contig

Struct Contig 

pub struct Contig(pub bool);
Specifies that the partitioning routines should try to produce partitions that are contiguous.

Note that if the input graph is not connected this option is ignored.

Tuple Fields

0: bool